var SecurityUtil = {
  /**
   * 所有需要过滤的on事件
   */
  reAllEvents: '',

  /**
   * script、link、frame标签, 注意大小写同时控制i
   */
  reBadTags: /(<\/?)(script|link|frame)([^\w])/ig,

  /**
   * srcdoc属性, 注意大小写同时控制i
   */
  reBadAttrs: /[\'"`\s\/](srcdoc)\s*=/ig,

  /**
   * scr/href属性
   */
  reBadJs: /[\'"`\s\/](src|href)\s*=\s*['"]?\s*(javascript\s*:\s*|data\s*:\s*text\/html)/ig,

  /**
   * img的src属性
   */
  reBadUrl: /(<img[\S\s]*src\s*=\s*['"]?)[\S]*\.(?!.*(jpg|jpeg|png|gif|bmp|svg)).*(\s*['"]?[\S\s]*\/?>)/ig,

  /**
   * 白名单正则, 正则根据业务参数计算
   */
  reWhiteList: '',

  /**
   * 默认域名白名单
   */
  whiteList: ['taobao.com', 'taobao.net', 'alibaba.com', 'alibaba-inc.com', 'alicdn.com', 'tbcdn.cn'],

  /**
   * 业务域白名单
   */
  buWhiteList: ['cainiao.com', 'cainiao-inc.com'],

  /**
   * 初始化工具集参数
   */
  initUtil: function initUtil() {
    // 初始事件正则
    var objOnEvents = {}; // init all events

    var doc = document;
    var arrDoms = [window, doc.createElement("form")];

    try {
      arrDoms.push(doc.createElement("img"));
      arrDoms.push(doc.createElement("iframe"));
      arrDoms.push(doc.createElement("object"));
      arrDoms.push(doc.createElement("embed"));
      arrDoms.push(doc.createElement("audio"));
    } catch (e) {
      console.error(e);
    }

    for (var i = 0, c = arrDoms.length; i < c; i++) {
      var dom = arrDoms[i];

      for (var onEvent in dom) {
        if (/^on/.test(onEvent)) {
          //取事件的key, 如onclick-->取click作为key
          objOnEvents[onEvent.substring(2)] = 1;
        }
      }
    }

    var arrAllEvents = [];

    for (var eventKey in objOnEvents) {
      arrAllEvents.push(eventKey);
    } //构造on事件的正则


    if (arrAllEvents.length > 0) {
      this.reAllEvents = new RegExp('([\'"`\\s\\/]on(?:' + arrAllEvents.join('|') + '))\\s*=', 'ig');
    } else {
      this.reAllEvents = /(['"`\s\/]on(\w+))\s*=/ig;
    }
  },

  /**
   * html无差别化，全部转义
   * 转义五个字符：< > ' " &
   * @param str 需要过滤的字符
   */
  htmlEncodeAll: function htmlEncodeAll(str) {
    return null === str ? "" : str.replace(/\&/g, "&amp;").replace(/\</g, "&lt;").replace(/\>/g, "&gt;").replace(/"/g, "&quot;").replace(/'/g, "&apos;");
  },

  /**
   * html无差别化，全部反转义
   * 反转义五个字符：&apos;  &quot; &gt; &lt; &amp;
   * @param str 需要反转义的字符
   * @returns {*}
   */
  htmlDecodeAll: function htmlDecodeAll(str) {
    return null === str ? "" : str.replace(/\&apos;/g, "'").replace(/\&quot;/g, '"').replace(/\&gt;/g, ">").replace(/\&lt;/g, "<").replace(/\&amp;/g, "&");
  },

  /**
   * 过滤危险字符
   * @param str 需要过滤的字符
   * @param tag 用于截取的字符
   * @returns {string|*}
   */
  escapeHtml: function escapeHtml(str, tag) {
    tag = tag ? tag : '0';
    str = String(str); // 过滤script & link & frame...

    str = str.replace(this.reBadTags, '$1$2' + tag + '$3'); // 过滤on事件

    str = str.replace(this.reAllEvents, '$1' + tag + '='); // 过滤srcdoc属性

    str = str.replace(this.reBadAttrs, ' $1' + tag + '='); // 过滤危险src/href= javascript: data:text/html

    str = str.replace(this.reBadJs, ' $1' + tag + '="'); // 过滤图片非法src

    str = str.replace(this.reBadUrl, '$1' + '" />');
    return str;
  },

  /**
   * 过滤白名单
   * @param url 需要检验的url
   * @returns {string} 白名单内的url则返回URL; 否则返回空
   */
  escapeUrl: function escapeUrl(url) {
    var all_white_list = this.whiteList.concat(this.buWhiteList);
    this.reWhiteList = new RegExp('^\s*https?:\/\/([^\/:]+.)?(' + all_white_list.join('|') + ')', 'ig');
    return this.reWhiteList.test(url) ? url : '';
  },

  /**
   * 检验白名单
   * @param url 需要检验的url
   * @returns {boolean} 是否是白名单内的url
   */
  validUrl: function validUrl(url) {
    var all_white_list = this.whiteList.concat(this.buWhiteList);
    this.reWhiteList = new RegExp('^\s*https?:\/\/([^\/:]+.)?(' + all_white_list.join('|') + ')', 'ig');
    return this.reWhiteList.test(url);
  },

  /**
   * 检验是否有非法输入
   * @param str 输入
   * @returns {boolean} 检验是否通过: true/通过; false/不通过
   */
  validHtml: function validHtml(str) {
    str = String(str);
    return !this.reAllEvents.test(str) && !this.reBadTags.test(str) && !this.reBadAttrs.test(str) && !this.reBadJs.test(str) && !this.reBadUrl.test(str);
  }
};
export default SecurityUtil;